# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['BucketServerSideEncryptionConfigurationArgs', 'BucketServerSideEncryptionConfiguration']

@pulumi.input_type
class BucketServerSideEncryptionConfigurationArgs:
    def __init__(__self__, *,
                 bucket: pulumi.Input[_builtins.str],
                 rules: pulumi.Input[Sequence[pulumi.Input['BucketServerSideEncryptionConfigurationRuleArgs']]]):
        """
        The set of arguments for constructing a BucketServerSideEncryptionConfiguration resource.
        :param pulumi.Input[_builtins.str] bucket: The bucket's name or regional ID.
        :param pulumi.Input[Sequence[pulumi.Input['BucketServerSideEncryptionConfigurationRuleArgs']]] rules: Set of server-side encryption configuration rules
        """
        pulumi.set(__self__, "bucket", bucket)
        pulumi.set(__self__, "rules", rules)

    @_builtins.property
    @pulumi.getter
    def bucket(self) -> pulumi.Input[_builtins.str]:
        """
        The bucket's name or regional ID.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "bucket", value)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> pulumi.Input[Sequence[pulumi.Input['BucketServerSideEncryptionConfigurationRuleArgs']]]:
        """
        Set of server-side encryption configuration rules
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: pulumi.Input[Sequence[pulumi.Input['BucketServerSideEncryptionConfigurationRuleArgs']]]):
        pulumi.set(self, "rules", value)


@pulumi.input_type
class _BucketServerSideEncryptionConfigurationState:
    def __init__(__self__, *,
                 bucket: Optional[pulumi.Input[_builtins.str]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input['BucketServerSideEncryptionConfigurationRuleArgs']]]] = None):
        """
        Input properties used for looking up and filtering BucketServerSideEncryptionConfiguration resources.
        :param pulumi.Input[_builtins.str] bucket: The bucket's name or regional ID.
        :param pulumi.Input[Sequence[pulumi.Input['BucketServerSideEncryptionConfigurationRuleArgs']]] rules: Set of server-side encryption configuration rules
        """
        if bucket is not None:
            pulumi.set(__self__, "bucket", bucket)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @_builtins.property
    @pulumi.getter
    def bucket(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The bucket's name or regional ID.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "bucket", value)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BucketServerSideEncryptionConfigurationRuleArgs']]]]:
        """
        Set of server-side encryption configuration rules
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BucketServerSideEncryptionConfigurationRuleArgs']]]]):
        pulumi.set(self, "rules", value)


@pulumi.type_token("scaleway:object/bucketServerSideEncryptionConfiguration:BucketServerSideEncryptionConfiguration")
class BucketServerSideEncryptionConfiguration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bucket: Optional[pulumi.Input[_builtins.str]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BucketServerSideEncryptionConfigurationRuleArgs', 'BucketServerSideEncryptionConfigurationRuleArgsDict']]]]] = None,
                 __props__=None):
        """
        The `object.BucketServerSideEncryptionConfiguration` resource allows you to manage server-side encryption configuration for [Scaleway Object Storage](https://www.scaleway.com/en/docs/object-storage/) buckets.

        Refer to the [dedicated documentation](https://www.scaleway.com/en/docs/object-storage/api-cli/enable-sse-one/) for more information on server-side encryption.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        test = scaleway.object.Bucket("test",
            name="my-unique-bucket-name",
            region="fr-par")
        test_bucket_server_side_encryption_configuration = scaleway.object.BucketServerSideEncryptionConfiguration("test",
            bucket=test.name,
            region="fr-par",
            rules=[{
                "apply_server_side_encryption_by_default": {
                    "sse_algorithm": "AES256",
                },
            }])
        ```

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        test = scaleway.object.Bucket("test", name="my-unique-bucket-name")
        test_bucket_server_side_encryption_configuration = scaleway.object.BucketServerSideEncryptionConfiguration("test",
            bucket=test.name,
            rules=[{
                "apply_server_side_encryption_by_default": {
                    "sse_algorithm": "AES256",
                },
            }])
        ```

        ## Import

        Server-side encryption configurations can be imported using the `{region}/{bucketName}` identifier, as shown below:

        bash

        ```sh
        $ pulumi import scaleway:object/bucketServerSideEncryptionConfiguration:BucketServerSideEncryptionConfiguration test fr-par/my-bucket-name
        ```

        ~> **Important:** The `project_id` attribute has a particular behavior with S3 products because the S3 API is scoped by project.

        If you are using a project different from the default one, you have to specify the project ID at the end of the import command.

        bash

        ```sh
        $ pulumi import scaleway:object/bucketServerSideEncryptionConfiguration:BucketServerSideEncryptionConfiguration test fr-par/my-bucket-name@11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] bucket: The bucket's name or regional ID.
        :param pulumi.Input[Sequence[pulumi.Input[Union['BucketServerSideEncryptionConfigurationRuleArgs', 'BucketServerSideEncryptionConfigurationRuleArgsDict']]]] rules: Set of server-side encryption configuration rules
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BucketServerSideEncryptionConfigurationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `object.BucketServerSideEncryptionConfiguration` resource allows you to manage server-side encryption configuration for [Scaleway Object Storage](https://www.scaleway.com/en/docs/object-storage/) buckets.

        Refer to the [dedicated documentation](https://www.scaleway.com/en/docs/object-storage/api-cli/enable-sse-one/) for more information on server-side encryption.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        test = scaleway.object.Bucket("test",
            name="my-unique-bucket-name",
            region="fr-par")
        test_bucket_server_side_encryption_configuration = scaleway.object.BucketServerSideEncryptionConfiguration("test",
            bucket=test.name,
            region="fr-par",
            rules=[{
                "apply_server_side_encryption_by_default": {
                    "sse_algorithm": "AES256",
                },
            }])
        ```

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        test = scaleway.object.Bucket("test", name="my-unique-bucket-name")
        test_bucket_server_side_encryption_configuration = scaleway.object.BucketServerSideEncryptionConfiguration("test",
            bucket=test.name,
            rules=[{
                "apply_server_side_encryption_by_default": {
                    "sse_algorithm": "AES256",
                },
            }])
        ```

        ## Import

        Server-side encryption configurations can be imported using the `{region}/{bucketName}` identifier, as shown below:

        bash

        ```sh
        $ pulumi import scaleway:object/bucketServerSideEncryptionConfiguration:BucketServerSideEncryptionConfiguration test fr-par/my-bucket-name
        ```

        ~> **Important:** The `project_id` attribute has a particular behavior with S3 products because the S3 API is scoped by project.

        If you are using a project different from the default one, you have to specify the project ID at the end of the import command.

        bash

        ```sh
        $ pulumi import scaleway:object/bucketServerSideEncryptionConfiguration:BucketServerSideEncryptionConfiguration test fr-par/my-bucket-name@11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param BucketServerSideEncryptionConfigurationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BucketServerSideEncryptionConfigurationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bucket: Optional[pulumi.Input[_builtins.str]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BucketServerSideEncryptionConfigurationRuleArgs', 'BucketServerSideEncryptionConfigurationRuleArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BucketServerSideEncryptionConfigurationArgs.__new__(BucketServerSideEncryptionConfigurationArgs)

            if bucket is None and not opts.urn:
                raise TypeError("Missing required property 'bucket'")
            __props__.__dict__["bucket"] = bucket
            if rules is None and not opts.urn:
                raise TypeError("Missing required property 'rules'")
            __props__.__dict__["rules"] = rules
        super(BucketServerSideEncryptionConfiguration, __self__).__init__(
            'scaleway:object/bucketServerSideEncryptionConfiguration:BucketServerSideEncryptionConfiguration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bucket: Optional[pulumi.Input[_builtins.str]] = None,
            rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BucketServerSideEncryptionConfigurationRuleArgs', 'BucketServerSideEncryptionConfigurationRuleArgsDict']]]]] = None) -> 'BucketServerSideEncryptionConfiguration':
        """
        Get an existing BucketServerSideEncryptionConfiguration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] bucket: The bucket's name or regional ID.
        :param pulumi.Input[Sequence[pulumi.Input[Union['BucketServerSideEncryptionConfigurationRuleArgs', 'BucketServerSideEncryptionConfigurationRuleArgsDict']]]] rules: Set of server-side encryption configuration rules
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BucketServerSideEncryptionConfigurationState.__new__(_BucketServerSideEncryptionConfigurationState)

        __props__.__dict__["bucket"] = bucket
        __props__.__dict__["rules"] = rules
        return BucketServerSideEncryptionConfiguration(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def bucket(self) -> pulumi.Output[_builtins.str]:
        """
        The bucket's name or regional ID.
        """
        return pulumi.get(self, "bucket")

    @_builtins.property
    @pulumi.getter
    def rules(self) -> pulumi.Output[Sequence['outputs.BucketServerSideEncryptionConfigurationRule']]:
        """
        Set of server-side encryption configuration rules
        """
        return pulumi.get(self, "rules")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['FileFilesystemArgs', 'FileFilesystem']

@pulumi.input_type
class FileFilesystemArgs:
    def __init__(__self__, *,
                 size_in_gb: pulumi.Input[_builtins.int],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a FileFilesystem resource.
        :param pulumi.Input[_builtins.int] size_in_gb: The size of the filesystem in bytes, with a granularity of 100 GB (10¹¹ bytes).
               - Minimum: 100 GB (100000000000 bytes)
               - Maximum: 10 TB (10000000000000 bytes)
        :param pulumi.Input[_builtins.str] name: The name of the filesystem. If not provided, a random name will be generated.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the server is
               associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region where the filesystem will be created (e.g., fr-par, nl-ams).
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A list of tags associated with the filesystem.
        """
        pulumi.set(__self__, "size_in_gb", size_in_gb)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="sizeInGb")
    def size_in_gb(self) -> pulumi.Input[_builtins.int]:
        """
        The size of the filesystem in bytes, with a granularity of 100 GB (10¹¹ bytes).
        - Minimum: 100 GB (100000000000 bytes)
        - Maximum: 10 TB (10000000000000 bytes)
        """
        return pulumi.get(self, "size_in_gb")

    @size_in_gb.setter
    def size_in_gb(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "size_in_gb", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the filesystem. If not provided, a random name will be generated.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the server is
        associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region where the filesystem will be created (e.g., fr-par, nl-ams).
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of tags associated with the filesystem.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _FileFilesystemState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 number_of_attachments: Optional[pulumi.Input[_builtins.int]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering FileFilesystem resources.
        :param pulumi.Input[_builtins.str] created_at: The date and time when the File Storage filesystem was created.
        :param pulumi.Input[_builtins.str] name: The name of the filesystem. If not provided, a random name will be generated.
        :param pulumi.Input[_builtins.int] number_of_attachments: The number of active attachments (mounts) on the filesystem.
        :param pulumi.Input[_builtins.str] organization_id: `organization_id`) The ID of the organization the user is associated with.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the server is
               associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region where the filesystem will be created (e.g., fr-par, nl-ams).
        :param pulumi.Input[_builtins.int] size_in_gb: The size of the filesystem in bytes, with a granularity of 100 GB (10¹¹ bytes).
               - Minimum: 100 GB (100000000000 bytes)
               - Maximum: 10 TB (10000000000000 bytes)
        :param pulumi.Input[_builtins.str] status: The current status of the filesystem. Possible values include creating, available, etc.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A list of tags associated with the filesystem.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update to the File Storage filesystem.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if number_of_attachments is not None:
            pulumi.set(__self__, "number_of_attachments", number_of_attachments)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if size_in_gb is not None:
            pulumi.set(__self__, "size_in_gb", size_in_gb)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time when the File Storage filesystem was created.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the filesystem. If not provided, a random name will be generated.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="numberOfAttachments")
    def number_of_attachments(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of active attachments (mounts) on the filesystem.
        """
        return pulumi.get(self, "number_of_attachments")

    @number_of_attachments.setter
    def number_of_attachments(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "number_of_attachments", value)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `organization_id`) The ID of the organization the user is associated with.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the server is
        associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region where the filesystem will be created (e.g., fr-par, nl-ams).
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="sizeInGb")
    def size_in_gb(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The size of the filesystem in bytes, with a granularity of 100 GB (10¹¹ bytes).
        - Minimum: 100 GB (100000000000 bytes)
        - Maximum: 10 TB (10000000000000 bytes)
        """
        return pulumi.get(self, "size_in_gb")

    @size_in_gb.setter
    def size_in_gb(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "size_in_gb", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The current status of the filesystem. Possible values include creating, available, etc.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of tags associated with the filesystem.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the last update to the File Storage filesystem.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("scaleway:index/fileFilesystem:FileFilesystem")
class FileFilesystem(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        > **This product is currently in private beta. To request access, please contact your Technical Account Manager.**

        Creates and manages a Scaleway File Storage filesystem in a specific region. A filesystem is a scalable storage resource that can be mounted on Compute instances and is typically used for share persistent storage between multiple instances (RWX).

        This resource allows you to define and manage the size, tags, and region of a filesystem, and track its creation and update timestamps, current status, and number of active attachments.

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        file = scaleway.FileFilesystem("file",
            name="my-nfs-filesystem",
            size_in_gb=100)
        ```

        ## Import

        File Storage filesystems can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/fileFilesystem:FileFilesystem main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] name: The name of the filesystem. If not provided, a random name will be generated.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the server is
               associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region where the filesystem will be created (e.g., fr-par, nl-ams).
        :param pulumi.Input[_builtins.int] size_in_gb: The size of the filesystem in bytes, with a granularity of 100 GB (10¹¹ bytes).
               - Minimum: 100 GB (100000000000 bytes)
               - Maximum: 10 TB (10000000000000 bytes)
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A list of tags associated with the filesystem.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FileFilesystemArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        > **This product is currently in private beta. To request access, please contact your Technical Account Manager.**

        Creates and manages a Scaleway File Storage filesystem in a specific region. A filesystem is a scalable storage resource that can be mounted on Compute instances and is typically used for share persistent storage between multiple instances (RWX).

        This resource allows you to define and manage the size, tags, and region of a filesystem, and track its creation and update timestamps, current status, and number of active attachments.

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        file = scaleway.FileFilesystem("file",
            name="my-nfs-filesystem",
            size_in_gb=100)
        ```

        ## Import

        File Storage filesystems can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/fileFilesystem:FileFilesystem main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param FileFilesystemArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FileFilesystemArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FileFilesystemArgs.__new__(FileFilesystemArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["region"] = region
            if size_in_gb is None and not opts.urn:
                raise TypeError("Missing required property 'size_in_gb'")
            __props__.__dict__["size_in_gb"] = size_in_gb
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created_at"] = None
            __props__.__dict__["number_of_attachments"] = None
            __props__.__dict__["organization_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
        super(FileFilesystem, __self__).__init__(
            'scaleway:index/fileFilesystem:FileFilesystem',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            number_of_attachments: Optional[pulumi.Input[_builtins.int]] = None,
            organization_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None) -> 'FileFilesystem':
        """
        Get an existing FileFilesystem resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_at: The date and time when the File Storage filesystem was created.
        :param pulumi.Input[_builtins.str] name: The name of the filesystem. If not provided, a random name will be generated.
        :param pulumi.Input[_builtins.int] number_of_attachments: The number of active attachments (mounts) on the filesystem.
        :param pulumi.Input[_builtins.str] organization_id: `organization_id`) The ID of the organization the user is associated with.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the server is
               associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region where the filesystem will be created (e.g., fr-par, nl-ams).
        :param pulumi.Input[_builtins.int] size_in_gb: The size of the filesystem in bytes, with a granularity of 100 GB (10¹¹ bytes).
               - Minimum: 100 GB (100000000000 bytes)
               - Maximum: 10 TB (10000000000000 bytes)
        :param pulumi.Input[_builtins.str] status: The current status of the filesystem. Possible values include creating, available, etc.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A list of tags associated with the filesystem.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update to the File Storage filesystem.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FileFilesystemState.__new__(_FileFilesystemState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["name"] = name
        __props__.__dict__["number_of_attachments"] = number_of_attachments
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["region"] = region
        __props__.__dict__["size_in_gb"] = size_in_gb
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        return FileFilesystem(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time when the File Storage filesystem was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the filesystem. If not provided, a random name will be generated.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="numberOfAttachments")
    def number_of_attachments(self) -> pulumi.Output[_builtins.int]:
        """
        The number of active attachments (mounts) on the filesystem.
        """
        return pulumi.get(self, "number_of_attachments")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[_builtins.str]:
        """
        `organization_id`) The ID of the organization the user is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the project the server is
        associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region where the filesystem will be created (e.g., fr-par, nl-ams).
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="sizeInGb")
    def size_in_gb(self) -> pulumi.Output[_builtins.int]:
        """
        The size of the filesystem in bytes, with a granularity of 100 GB (10¹¹ bytes).
        - Minimum: 100 GB (100000000000 bytes)
        - Maximum: 10 TB (10000000000000 bytes)
        """
        return pulumi.get(self, "size_in_gb")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The current status of the filesystem. Possible values include creating, available, etc.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        A list of tags associated with the filesystem.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the last update to the File Storage filesystem.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'DomainReputationArgs',
    'DomainReputationArgsDict',
]

MYPY = False

if not MYPY:
    class DomainReputationArgsDict(TypedDict):
        previous_score: NotRequired[pulumi.Input[_builtins.int]]
        """
        The previously-calculated domain's reputation score.
        """
        previous_scored_at: NotRequired[pulumi.Input[_builtins.str]]
        """
        The time and date the previous reputation score was calculated.
        """
        score: NotRequired[pulumi.Input[_builtins.int]]
        """
        A range from 0 to 100 that determines your domain's reputation score.
        """
        scored_at: NotRequired[pulumi.Input[_builtins.str]]
        """
        The time and date the score was calculated.
        """
        status: NotRequired[pulumi.Input[_builtins.str]]
        """
        The status of the domain's reputation.
        """
elif False:
    DomainReputationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DomainReputationArgs:
    def __init__(__self__, *,
                 previous_score: Optional[pulumi.Input[_builtins.int]] = None,
                 previous_scored_at: Optional[pulumi.Input[_builtins.str]] = None,
                 score: Optional[pulumi.Input[_builtins.int]] = None,
                 scored_at: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.int] previous_score: The previously-calculated domain's reputation score.
        :param pulumi.Input[_builtins.str] previous_scored_at: The time and date the previous reputation score was calculated.
        :param pulumi.Input[_builtins.int] score: A range from 0 to 100 that determines your domain's reputation score.
        :param pulumi.Input[_builtins.str] scored_at: The time and date the score was calculated.
        :param pulumi.Input[_builtins.str] status: The status of the domain's reputation.
        """
        if previous_score is not None:
            pulumi.set(__self__, "previous_score", previous_score)
        if previous_scored_at is not None:
            pulumi.set(__self__, "previous_scored_at", previous_scored_at)
        if score is not None:
            pulumi.set(__self__, "score", score)
        if scored_at is not None:
            pulumi.set(__self__, "scored_at", scored_at)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="previousScore")
    def previous_score(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The previously-calculated domain's reputation score.
        """
        return pulumi.get(self, "previous_score")

    @previous_score.setter
    def previous_score(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "previous_score", value)

    @_builtins.property
    @pulumi.getter(name="previousScoredAt")
    def previous_scored_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The time and date the previous reputation score was calculated.
        """
        return pulumi.get(self, "previous_scored_at")

    @previous_scored_at.setter
    def previous_scored_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "previous_scored_at", value)

    @_builtins.property
    @pulumi.getter
    def score(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        A range from 0 to 100 that determines your domain's reputation score.
        """
        return pulumi.get(self, "score")

    @score.setter
    def score(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "score", value)

    @_builtins.property
    @pulumi.getter(name="scoredAt")
    def scored_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The time and date the score was calculated.
        """
        return pulumi.get(self, "scored_at")

    @scored_at.setter
    def scored_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "scored_at", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the domain's reputation.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InstancePrivateNicArgs', 'InstancePrivateNic']

@pulumi.input_type
class InstancePrivateNicArgs:
    def __init__(__self__, *,
                 private_network_id: pulumi.Input[_builtins.str],
                 server_id: pulumi.Input[_builtins.str],
                 ip_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ipam_ip_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 private_ips: Optional[pulumi.Input[Sequence[pulumi.Input['InstancePrivateNicPrivateIpArgs']]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a InstancePrivateNic resource.
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the private network attached to.
        :param pulumi.Input[_builtins.str] server_id: The ID of the server associated with.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_ids: IPAM ip list, should be for internal use only
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ipam_ip_ids: IPAM IDs of a pre-reserved IP addresses to assign to the Instance in the requested private network.
        :param pulumi.Input[Sequence[pulumi.Input['InstancePrivateNicPrivateIpArgs']]] private_ips: The list of private IPv4 and IPv6 addresses associated with the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the private NIC.
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the server must be created.
        """
        pulumi.set(__self__, "private_network_id", private_network_id)
        pulumi.set(__self__, "server_id", server_id)
        if ip_ids is not None:
            pulumi.set(__self__, "ip_ids", ip_ids)
        if ipam_ip_ids is not None:
            pulumi.set(__self__, "ipam_ip_ids", ipam_ip_ids)
        if private_ips is not None:
            pulumi.set(__self__, "private_ips", private_ips)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the private network attached to.
        """
        return pulumi.get(self, "private_network_id")

    @private_network_id.setter
    def private_network_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "private_network_id", value)

    @_builtins.property
    @pulumi.getter(name="serverId")
    def server_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the server associated with.
        """
        return pulumi.get(self, "server_id")

    @server_id.setter
    def server_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "server_id", value)

    @_builtins.property
    @pulumi.getter(name="ipIds")
    def ip_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        IPAM ip list, should be for internal use only
        """
        return pulumi.get(self, "ip_ids")

    @ip_ids.setter
    def ip_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ip_ids", value)

    @_builtins.property
    @pulumi.getter(name="ipamIpIds")
    def ipam_ip_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        IPAM IDs of a pre-reserved IP addresses to assign to the Instance in the requested private network.
        """
        return pulumi.get(self, "ipam_ip_ids")

    @ipam_ip_ids.setter
    def ipam_ip_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ipam_ip_ids", value)

    @_builtins.property
    @pulumi.getter(name="privateIps")
    def private_ips(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstancePrivateNicPrivateIpArgs']]]]:
        """
        The list of private IPv4 and IPv6 addresses associated with the resource.
        """
        return pulumi.get(self, "private_ips")

    @private_ips.setter
    def private_ips(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstancePrivateNicPrivateIpArgs']]]]):
        pulumi.set(self, "private_ips", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The tags associated with the private NIC.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `zone`) The zone in which the server must be created.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class _InstancePrivateNicState:
    def __init__(__self__, *,
                 ip_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ipam_ip_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 mac_address: Optional[pulumi.Input[_builtins.str]] = None,
                 private_ips: Optional[pulumi.Input[Sequence[pulumi.Input['InstancePrivateNicPrivateIpArgs']]]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 server_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering InstancePrivateNic resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_ids: IPAM ip list, should be for internal use only
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ipam_ip_ids: IPAM IDs of a pre-reserved IP addresses to assign to the Instance in the requested private network.
        :param pulumi.Input[_builtins.str] mac_address: The MAC address of the private NIC.
        :param pulumi.Input[Sequence[pulumi.Input['InstancePrivateNicPrivateIpArgs']]] private_ips: The list of private IPv4 and IPv6 addresses associated with the resource.
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the private network attached to.
        :param pulumi.Input[_builtins.str] server_id: The ID of the server associated with.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the private NIC.
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the server must be created.
        """
        if ip_ids is not None:
            pulumi.set(__self__, "ip_ids", ip_ids)
        if ipam_ip_ids is not None:
            pulumi.set(__self__, "ipam_ip_ids", ipam_ip_ids)
        if mac_address is not None:
            pulumi.set(__self__, "mac_address", mac_address)
        if private_ips is not None:
            pulumi.set(__self__, "private_ips", private_ips)
        if private_network_id is not None:
            pulumi.set(__self__, "private_network_id", private_network_id)
        if server_id is not None:
            pulumi.set(__self__, "server_id", server_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="ipIds")
    def ip_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        IPAM ip list, should be for internal use only
        """
        return pulumi.get(self, "ip_ids")

    @ip_ids.setter
    def ip_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ip_ids", value)

    @_builtins.property
    @pulumi.getter(name="ipamIpIds")
    def ipam_ip_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        IPAM IDs of a pre-reserved IP addresses to assign to the Instance in the requested private network.
        """
        return pulumi.get(self, "ipam_ip_ids")

    @ipam_ip_ids.setter
    def ipam_ip_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ipam_ip_ids", value)

    @_builtins.property
    @pulumi.getter(name="macAddress")
    def mac_address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The MAC address of the private NIC.
        """
        return pulumi.get(self, "mac_address")

    @mac_address.setter
    def mac_address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mac_address", value)

    @_builtins.property
    @pulumi.getter(name="privateIps")
    def private_ips(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstancePrivateNicPrivateIpArgs']]]]:
        """
        The list of private IPv4 and IPv6 addresses associated with the resource.
        """
        return pulumi.get(self, "private_ips")

    @private_ips.setter
    def private_ips(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstancePrivateNicPrivateIpArgs']]]]):
        pulumi.set(self, "private_ips", value)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the private network attached to.
        """
        return pulumi.get(self, "private_network_id")

    @private_network_id.setter
    def private_network_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "private_network_id", value)

    @_builtins.property
    @pulumi.getter(name="serverId")
    def server_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the server associated with.
        """
        return pulumi.get(self, "server_id")

    @server_id.setter
    def server_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "server_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The tags associated with the private NIC.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `zone`) The zone in which the server must be created.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


warnings.warn("""scaleway.index/instanceprivatenic.InstancePrivateNic has been deprecated in favor of scaleway.instance/privatenic.PrivateNic""", DeprecationWarning)


@pulumi.type_token("scaleway:index/instancePrivateNic:InstancePrivateNic")
class InstancePrivateNic(pulumi.CustomResource):
    warnings.warn("""scaleway.index/instanceprivatenic.InstancePrivateNic has been deprecated in favor of scaleway.instance/privatenic.PrivateNic""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ip_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ipam_ip_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 private_ips: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstancePrivateNicPrivateIpArgs', 'InstancePrivateNicPrivateIpArgsDict']]]]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 server_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Instance Private NICs. For more information, see
        the [API documentation](https://www.scaleway.com/en/developers/api/instance/#path-private-nics-list-all-private-nics).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        pnic01 = scaleway.instance.PrivateNic("pnic01",
            server_id="fr-par-1/11111111-1111-1111-1111-111111111111",
            private_network_id="fr-par-1/aaaaaaaa-aaaa-aaaa-aaaa-aaaaaaaaaaaa")
        ```

        ### With zone

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        pn01 = scaleway.network.PrivateNetwork("pn01",
            name="private_network_instance",
            region="fr-par")
        base = scaleway.instance.Server("base",
            image="ubuntu_jammy",
            type="DEV1-S",
            zone=pn01.zone)
        pnic01 = scaleway.instance.PrivateNic("pnic01",
            server_id=base.id,
            private_network_id=pn01.id,
            zone=pn01.zone)
        ```

        ### With IPAM IP IDs

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        vpc01 = scaleway.network.Vpc("vpc01", name="vpc_instance")
        pn01 = scaleway.network.PrivateNetwork("pn01",
            name="private_network_instance",
            ipv4_subnet={
                "subnet": "172.16.64.0/22",
            },
            vpc_id=vpc01.id)
        ip01 = scaleway.ipam.Ip("ip01",
            address="172.16.64.7",
            sources=[{
                "private_network_id": pn01.id,
            }])
        server01 = scaleway.instance.Server("server01",
            image="ubuntu_focal",
            type="PLAY2-MICRO")
        pnic01 = scaleway.instance.PrivateNic("pnic01",
            private_network_id=pn01.id,
            server_id=server01.id,
            ipam_ip_ids=[ip01.id])
        ```

        ## Import

        Private NICs can be imported using the `{zone}/{server_id}/{private_nic_id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/instancePrivateNic:InstancePrivateNic pnic01 fr-par-1/11111111-1111-1111-1111-111111111111/22222222-2222-2222-2222-222222222222
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_ids: IPAM ip list, should be for internal use only
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ipam_ip_ids: IPAM IDs of a pre-reserved IP addresses to assign to the Instance in the requested private network.
        :param pulumi.Input[Sequence[pulumi.Input[Union['InstancePrivateNicPrivateIpArgs', 'InstancePrivateNicPrivateIpArgsDict']]]] private_ips: The list of private IPv4 and IPv6 addresses associated with the resource.
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the private network attached to.
        :param pulumi.Input[_builtins.str] server_id: The ID of the server associated with.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the private NIC.
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the server must be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstancePrivateNicArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Instance Private NICs. For more information, see
        the [API documentation](https://www.scaleway.com/en/developers/api/instance/#path-private-nics-list-all-private-nics).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        pnic01 = scaleway.instance.PrivateNic("pnic01",
            server_id="fr-par-1/11111111-1111-1111-1111-111111111111",
            private_network_id="fr-par-1/aaaaaaaa-aaaa-aaaa-aaaa-aaaaaaaaaaaa")
        ```

        ### With zone

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        pn01 = scaleway.network.PrivateNetwork("pn01",
            name="private_network_instance",
            region="fr-par")
        base = scaleway.instance.Server("base",
            image="ubuntu_jammy",
            type="DEV1-S",
            zone=pn01.zone)
        pnic01 = scaleway.instance.PrivateNic("pnic01",
            server_id=base.id,
            private_network_id=pn01.id,
            zone=pn01.zone)
        ```

        ### With IPAM IP IDs

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        vpc01 = scaleway.network.Vpc("vpc01", name="vpc_instance")
        pn01 = scaleway.network.PrivateNetwork("pn01",
            name="private_network_instance",
            ipv4_subnet={
                "subnet": "172.16.64.0/22",
            },
            vpc_id=vpc01.id)
        ip01 = scaleway.ipam.Ip("ip01",
            address="172.16.64.7",
            sources=[{
                "private_network_id": pn01.id,
            }])
        server01 = scaleway.instance.Server("server01",
            image="ubuntu_focal",
            type="PLAY2-MICRO")
        pnic01 = scaleway.instance.PrivateNic("pnic01",
            private_network_id=pn01.id,
            server_id=server01.id,
            ipam_ip_ids=[ip01.id])
        ```

        ## Import

        Private NICs can be imported using the `{zone}/{server_id}/{private_nic_id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/instancePrivateNic:InstancePrivateNic pnic01 fr-par-1/11111111-1111-1111-1111-111111111111/22222222-2222-2222-2222-222222222222
        ```

        :param str resource_name: The name of the resource.
        :param InstancePrivateNicArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstancePrivateNicArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ip_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ipam_ip_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 private_ips: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstancePrivateNicPrivateIpArgs', 'InstancePrivateNicPrivateIpArgsDict']]]]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 server_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""InstancePrivateNic is deprecated: scaleway.index/instanceprivatenic.InstancePrivateNic has been deprecated in favor of scaleway.instance/privatenic.PrivateNic""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstancePrivateNicArgs.__new__(InstancePrivateNicArgs)

            __props__.__dict__["ip_ids"] = ip_ids
            __props__.__dict__["ipam_ip_ids"] = ipam_ip_ids
            __props__.__dict__["private_ips"] = private_ips
            if private_network_id is None and not opts.urn:
                raise TypeError("Missing required property 'private_network_id'")
            __props__.__dict__["private_network_id"] = private_network_id
            if server_id is None and not opts.urn:
                raise TypeError("Missing required property 'server_id'")
            __props__.__dict__["server_id"] = server_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["zone"] = zone
            __props__.__dict__["mac_address"] = None
        super(InstancePrivateNic, __self__).__init__(
            'scaleway:index/instancePrivateNic:InstancePrivateNic',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ip_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            ipam_ip_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            mac_address: Optional[pulumi.Input[_builtins.str]] = None,
            private_ips: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstancePrivateNicPrivateIpArgs', 'InstancePrivateNicPrivateIpArgsDict']]]]] = None,
            private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
            server_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            zone: Optional[pulumi.Input[_builtins.str]] = None) -> 'InstancePrivateNic':
        """
        Get an existing InstancePrivateNic resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_ids: IPAM ip list, should be for internal use only
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ipam_ip_ids: IPAM IDs of a pre-reserved IP addresses to assign to the Instance in the requested private network.
        :param pulumi.Input[_builtins.str] mac_address: The MAC address of the private NIC.
        :param pulumi.Input[Sequence[pulumi.Input[Union['InstancePrivateNicPrivateIpArgs', 'InstancePrivateNicPrivateIpArgsDict']]]] private_ips: The list of private IPv4 and IPv6 addresses associated with the resource.
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the private network attached to.
        :param pulumi.Input[_builtins.str] server_id: The ID of the server associated with.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the private NIC.
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the server must be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstancePrivateNicState.__new__(_InstancePrivateNicState)

        __props__.__dict__["ip_ids"] = ip_ids
        __props__.__dict__["ipam_ip_ids"] = ipam_ip_ids
        __props__.__dict__["mac_address"] = mac_address
        __props__.__dict__["private_ips"] = private_ips
        __props__.__dict__["private_network_id"] = private_network_id
        __props__.__dict__["server_id"] = server_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["zone"] = zone
        return InstancePrivateNic(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="ipIds")
    def ip_ids(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        IPAM ip list, should be for internal use only
        """
        return pulumi.get(self, "ip_ids")

    @_builtins.property
    @pulumi.getter(name="ipamIpIds")
    def ipam_ip_ids(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        IPAM IDs of a pre-reserved IP addresses to assign to the Instance in the requested private network.
        """
        return pulumi.get(self, "ipam_ip_ids")

    @_builtins.property
    @pulumi.getter(name="macAddress")
    def mac_address(self) -> pulumi.Output[_builtins.str]:
        """
        The MAC address of the private NIC.
        """
        return pulumi.get(self, "mac_address")

    @_builtins.property
    @pulumi.getter(name="privateIps")
    def private_ips(self) -> pulumi.Output[Sequence['outputs.InstancePrivateNicPrivateIp']]:
        """
        The list of private IPv4 and IPv6 addresses associated with the resource.
        """
        return pulumi.get(self, "private_ips")

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the private network attached to.
        """
        return pulumi.get(self, "private_network_id")

    @_builtins.property
    @pulumi.getter(name="serverId")
    def server_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the server associated with.
        """
        return pulumi.get(self, "server_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The tags associated with the private NIC.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `zone`) The zone in which the server must be created.
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SqsQueueArgs', 'SqsQueue']

@pulumi.input_type
class SqsQueueArgs:
    def __init__(__self__, *,
                 access_key: pulumi.Input[_builtins.str],
                 secret_key: pulumi.Input[_builtins.str],
                 content_based_deduplication: Optional[pulumi.Input[_builtins.bool]] = None,
                 dead_letter_queue: Optional[pulumi.Input['SqsQueueDeadLetterQueueArgs']] = None,
                 fifo_queue: Optional[pulumi.Input[_builtins.bool]] = None,
                 message_max_age: Optional[pulumi.Input[_builtins.int]] = None,
                 message_max_size: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 name_prefix: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 receive_wait_time_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 sqs_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 visibility_timeout_seconds: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a SqsQueue resource.
        :param pulumi.Input[_builtins.str] access_key: The access key of the SQS queue.
        :param pulumi.Input[_builtins.str] secret_key: The secret key of the SQS queue.
        :param pulumi.Input[_builtins.bool] content_based_deduplication: Specifies whether to enable content-based deduplication. Defaults to `false`.
        :param pulumi.Input['SqsQueueDeadLetterQueueArgs'] dead_letter_queue: Configuration for the dead letter queue. See Dead Letter Queue below for details.
        :param pulumi.Input[_builtins.bool] fifo_queue: Whether the queue is a FIFO queue. If true, the queue name must end with .fifo. Defaults to `false`.
        :param pulumi.Input[_builtins.int] message_max_age: The number of seconds the queue retains a message. Must be between 60 and 1_209_600. Defaults to 345_600.
        :param pulumi.Input[_builtins.int] message_max_size: The maximum size of a message. Should be in bytes. Must be between 1024 and 262_144. Defaults to 262_144.
        :param pulumi.Input[_builtins.str] name: The unique name of the SQS queue. Either `name` or `name_prefix` is required. Conflicts with `name_prefix`.
        :param pulumi.Input[_builtins.str] name_prefix: Creates a unique name beginning with the specified prefix. Conflicts with `name`.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project in which SQS is enabled.
        :param pulumi.Input[_builtins.int] receive_wait_time_seconds: The number of seconds to wait for a message to arrive in the queue before returning. Must be between 0 and 20. Defaults to 0.
        :param pulumi.Input[_builtins.str] region: `region`). The region in which SQS is enabled.
        :param pulumi.Input[_builtins.str] sqs_endpoint: The endpoint of the SQS queue. Can contain a {region} placeholder. Defaults to `https://sqs.mnq.{region}.scaleway.com`.
        :param pulumi.Input[_builtins.int] visibility_timeout_seconds: The number of seconds a message is hidden from other consumers. Must be between 0 and 43_200. Defaults to 30.
        """
        pulumi.set(__self__, "access_key", access_key)
        pulumi.set(__self__, "secret_key", secret_key)
        if content_based_deduplication is not None:
            pulumi.set(__self__, "content_based_deduplication", content_based_deduplication)
        if dead_letter_queue is not None:
            pulumi.set(__self__, "dead_letter_queue", dead_letter_queue)
        if fifo_queue is not None:
            pulumi.set(__self__, "fifo_queue", fifo_queue)
        if message_max_age is not None:
            pulumi.set(__self__, "message_max_age", message_max_age)
        if message_max_size is not None:
            pulumi.set(__self__, "message_max_size", message_max_size)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if name_prefix is not None:
            pulumi.set(__self__, "name_prefix", name_prefix)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if receive_wait_time_seconds is not None:
            pulumi.set(__self__, "receive_wait_time_seconds", receive_wait_time_seconds)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if sqs_endpoint is not None:
            pulumi.set(__self__, "sqs_endpoint", sqs_endpoint)
        if visibility_timeout_seconds is not None:
            pulumi.set(__self__, "visibility_timeout_seconds", visibility_timeout_seconds)

    @_builtins.property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> pulumi.Input[_builtins.str]:
        """
        The access key of the SQS queue.
        """
        return pulumi.get(self, "access_key")

    @access_key.setter
    def access_key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "access_key", value)

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> pulumi.Input[_builtins.str]:
        """
        The secret key of the SQS queue.
        """
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "secret_key", value)

    @_builtins.property
    @pulumi.getter(name="contentBasedDeduplication")
    def content_based_deduplication(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether to enable content-based deduplication. Defaults to `false`.
        """
        return pulumi.get(self, "content_based_deduplication")

    @content_based_deduplication.setter
    def content_based_deduplication(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "content_based_deduplication", value)

    @_builtins.property
    @pulumi.getter(name="deadLetterQueue")
    def dead_letter_queue(self) -> Optional[pulumi.Input['SqsQueueDeadLetterQueueArgs']]:
        """
        Configuration for the dead letter queue. See Dead Letter Queue below for details.
        """
        return pulumi.get(self, "dead_letter_queue")

    @dead_letter_queue.setter
    def dead_letter_queue(self, value: Optional[pulumi.Input['SqsQueueDeadLetterQueueArgs']]):
        pulumi.set(self, "dead_letter_queue", value)

    @_builtins.property
    @pulumi.getter(name="fifoQueue")
    def fifo_queue(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the queue is a FIFO queue. If true, the queue name must end with .fifo. Defaults to `false`.
        """
        return pulumi.get(self, "fifo_queue")

    @fifo_queue.setter
    def fifo_queue(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "fifo_queue", value)

    @_builtins.property
    @pulumi.getter(name="messageMaxAge")
    def message_max_age(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of seconds the queue retains a message. Must be between 60 and 1_209_600. Defaults to 345_600.
        """
        return pulumi.get(self, "message_max_age")

    @message_max_age.setter
    def message_max_age(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "message_max_age", value)

    @_builtins.property
    @pulumi.getter(name="messageMaxSize")
    def message_max_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum size of a message. Should be in bytes. Must be between 1024 and 262_144. Defaults to 262_144.
        """
        return pulumi.get(self, "message_max_size")

    @message_max_size.setter
    def message_max_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "message_max_size", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique name of the SQS queue. Either `name` or `name_prefix` is required. Conflicts with `name_prefix`.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="namePrefix")
    def name_prefix(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Creates a unique name beginning with the specified prefix. Conflicts with `name`.
        """
        return pulumi.get(self, "name_prefix")

    @name_prefix.setter
    def name_prefix(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name_prefix", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the Project in which SQS is enabled.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="receiveWaitTimeSeconds")
    def receive_wait_time_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of seconds to wait for a message to arrive in the queue before returning. Must be between 0 and 20. Defaults to 0.
        """
        return pulumi.get(self, "receive_wait_time_seconds")

    @receive_wait_time_seconds.setter
    def receive_wait_time_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "receive_wait_time_seconds", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`). The region in which SQS is enabled.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="sqsEndpoint")
    def sqs_endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The endpoint of the SQS queue. Can contain a {region} placeholder. Defaults to `https://sqs.mnq.{region}.scaleway.com`.
        """
        return pulumi.get(self, "sqs_endpoint")

    @sqs_endpoint.setter
    def sqs_endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sqs_endpoint", value)

    @_builtins.property
    @pulumi.getter(name="visibilityTimeoutSeconds")
    def visibility_timeout_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of seconds a message is hidden from other consumers. Must be between 0 and 43_200. Defaults to 30.
        """
        return pulumi.get(self, "visibility_timeout_seconds")

    @visibility_timeout_seconds.setter
    def visibility_timeout_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "visibility_timeout_seconds", value)


@pulumi.input_type
class _SqsQueueState:
    def __init__(__self__, *,
                 access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 arn: Optional[pulumi.Input[_builtins.str]] = None,
                 content_based_deduplication: Optional[pulumi.Input[_builtins.bool]] = None,
                 dead_letter_queue: Optional[pulumi.Input['SqsQueueDeadLetterQueueArgs']] = None,
                 fifo_queue: Optional[pulumi.Input[_builtins.bool]] = None,
                 message_max_age: Optional[pulumi.Input[_builtins.int]] = None,
                 message_max_size: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 name_prefix: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 receive_wait_time_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 sqs_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 visibility_timeout_seconds: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering SqsQueue resources.
        :param pulumi.Input[_builtins.str] access_key: The access key of the SQS queue.
        :param pulumi.Input[_builtins.str] arn: The ARN of the queue
        :param pulumi.Input[_builtins.bool] content_based_deduplication: Specifies whether to enable content-based deduplication. Defaults to `false`.
        :param pulumi.Input['SqsQueueDeadLetterQueueArgs'] dead_letter_queue: Configuration for the dead letter queue. See Dead Letter Queue below for details.
        :param pulumi.Input[_builtins.bool] fifo_queue: Whether the queue is a FIFO queue. If true, the queue name must end with .fifo. Defaults to `false`.
        :param pulumi.Input[_builtins.int] message_max_age: The number of seconds the queue retains a message. Must be between 60 and 1_209_600. Defaults to 345_600.
        :param pulumi.Input[_builtins.int] message_max_size: The maximum size of a message. Should be in bytes. Must be between 1024 and 262_144. Defaults to 262_144.
        :param pulumi.Input[_builtins.str] name: The unique name of the SQS queue. Either `name` or `name_prefix` is required. Conflicts with `name_prefix`.
        :param pulumi.Input[_builtins.str] name_prefix: Creates a unique name beginning with the specified prefix. Conflicts with `name`.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project in which SQS is enabled.
        :param pulumi.Input[_builtins.int] receive_wait_time_seconds: The number of seconds to wait for a message to arrive in the queue before returning. Must be between 0 and 20. Defaults to 0.
        :param pulumi.Input[_builtins.str] region: `region`). The region in which SQS is enabled.
        :param pulumi.Input[_builtins.str] secret_key: The secret key of the SQS queue.
        :param pulumi.Input[_builtins.str] sqs_endpoint: The endpoint of the SQS queue. Can contain a {region} placeholder. Defaults to `https://sqs.mnq.{region}.scaleway.com`.
        :param pulumi.Input[_builtins.str] url: The URL of the queue.
        :param pulumi.Input[_builtins.int] visibility_timeout_seconds: The number of seconds a message is hidden from other consumers. Must be between 0 and 43_200. Defaults to 30.
        """
        if access_key is not None:
            pulumi.set(__self__, "access_key", access_key)
        if arn is not None:
            pulumi.set(__self__, "arn", arn)
        if content_based_deduplication is not None:
            pulumi.set(__self__, "content_based_deduplication", content_based_deduplication)
        if dead_letter_queue is not None:
            pulumi.set(__self__, "dead_letter_queue", dead_letter_queue)
        if fifo_queue is not None:
            pulumi.set(__self__, "fifo_queue", fifo_queue)
        if message_max_age is not None:
            pulumi.set(__self__, "message_max_age", message_max_age)
        if message_max_size is not None:
            pulumi.set(__self__, "message_max_size", message_max_size)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if name_prefix is not None:
            pulumi.set(__self__, "name_prefix", name_prefix)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if receive_wait_time_seconds is not None:
            pulumi.set(__self__, "receive_wait_time_seconds", receive_wait_time_seconds)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if secret_key is not None:
            pulumi.set(__self__, "secret_key", secret_key)
        if sqs_endpoint is not None:
            pulumi.set(__self__, "sqs_endpoint", sqs_endpoint)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if visibility_timeout_seconds is not None:
            pulumi.set(__self__, "visibility_timeout_seconds", visibility_timeout_seconds)

    @_builtins.property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The access key of the SQS queue.
        """
        return pulumi.get(self, "access_key")

    @access_key.setter
    def access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_key", value)

    @_builtins.property
    @pulumi.getter
    def arn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ARN of the queue
        """
        return pulumi.get(self, "arn")

    @arn.setter
    def arn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "arn", value)

    @_builtins.property
    @pulumi.getter(name="contentBasedDeduplication")
    def content_based_deduplication(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether to enable content-based deduplication. Defaults to `false`.
        """
        return pulumi.get(self, "content_based_deduplication")

    @content_based_deduplication.setter
    def content_based_deduplication(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "content_based_deduplication", value)

    @_builtins.property
    @pulumi.getter(name="deadLetterQueue")
    def dead_letter_queue(self) -> Optional[pulumi.Input['SqsQueueDeadLetterQueueArgs']]:
        """
        Configuration for the dead letter queue. See Dead Letter Queue below for details.
        """
        return pulumi.get(self, "dead_letter_queue")

    @dead_letter_queue.setter
    def dead_letter_queue(self, value: Optional[pulumi.Input['SqsQueueDeadLetterQueueArgs']]):
        pulumi.set(self, "dead_letter_queue", value)

    @_builtins.property
    @pulumi.getter(name="fifoQueue")
    def fifo_queue(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the queue is a FIFO queue. If true, the queue name must end with .fifo. Defaults to `false`.
        """
        return pulumi.get(self, "fifo_queue")

    @fifo_queue.setter
    def fifo_queue(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "fifo_queue", value)

    @_builtins.property
    @pulumi.getter(name="messageMaxAge")
    def message_max_age(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of seconds the queue retains a message. Must be between 60 and 1_209_600. Defaults to 345_600.
        """
        return pulumi.get(self, "message_max_age")

    @message_max_age.setter
    def message_max_age(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "message_max_age", value)

    @_builtins.property
    @pulumi.getter(name="messageMaxSize")
    def message_max_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum size of a message. Should be in bytes. Must be between 1024 and 262_144. Defaults to 262_144.
        """
        return pulumi.get(self, "message_max_size")

    @message_max_size.setter
    def message_max_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "message_max_size", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique name of the SQS queue. Either `name` or `name_prefix` is required. Conflicts with `name_prefix`.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="namePrefix")
    def name_prefix(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Creates a unique name beginning with the specified prefix. Conflicts with `name`.
        """
        return pulumi.get(self, "name_prefix")

    @name_prefix.setter
    def name_prefix(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name_prefix", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the Project in which SQS is enabled.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="receiveWaitTimeSeconds")
    def receive_wait_time_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of seconds to wait for a message to arrive in the queue before returning. Must be between 0 and 20. Defaults to 0.
        """
        return pulumi.get(self, "receive_wait_time_seconds")

    @receive_wait_time_seconds.setter
    def receive_wait_time_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "receive_wait_time_seconds", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`). The region in which SQS is enabled.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The secret key of the SQS queue.
        """
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_key", value)

    @_builtins.property
    @pulumi.getter(name="sqsEndpoint")
    def sqs_endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The endpoint of the SQS queue. Can contain a {region} placeholder. Defaults to `https://sqs.mnq.{region}.scaleway.com`.
        """
        return pulumi.get(self, "sqs_endpoint")

    @sqs_endpoint.setter
    def sqs_endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sqs_endpoint", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL of the queue.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter(name="visibilityTimeoutSeconds")
    def visibility_timeout_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of seconds a message is hidden from other consumers. Must be between 0 and 43_200. Defaults to 30.
        """
        return pulumi.get(self, "visibility_timeout_seconds")

    @visibility_timeout_seconds.setter
    def visibility_timeout_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "visibility_timeout_seconds", value)


@pulumi.type_token("scaleway:mnq/sqsQueue:SqsQueue")
class SqsQueue(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 content_based_deduplication: Optional[pulumi.Input[_builtins.bool]] = None,
                 dead_letter_queue: Optional[pulumi.Input[Union['SqsQueueDeadLetterQueueArgs', 'SqsQueueDeadLetterQueueArgsDict']]] = None,
                 fifo_queue: Optional[pulumi.Input[_builtins.bool]] = None,
                 message_max_age: Optional[pulumi.Input[_builtins.int]] = None,
                 message_max_size: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 name_prefix: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 receive_wait_time_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 sqs_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 visibility_timeout_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Messaging and Queuing SQS queues.
        For further information, see
        our [main documentation](https://www.scaleway.com/en/docs/messaging/how-to/create-manage-queues/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.mnq.Sqs("main")
        main_sqs_credentials = scaleway.mnq.SqsCredentials("main",
            project_id=main.project_id,
            name="sqs-credentials",
            permissions={
                "can_manage": True,
                "can_receive": False,
                "can_publish": False,
            })
        main_sqs_queue = scaleway.mnq.SqsQueue("main",
            project_id=main.project_id,
            name="my-queue",
            sqs_endpoint=main.endpoint,
            access_key=main_sqs_credentials.access_key,
            secret_key=main_sqs_credentials.secret_key)
        ```

        ### With Dead Letter Queue

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.mnq.Sqs("main")
        main_sqs_credentials = scaleway.mnq.SqsCredentials("main",
            project_id=main.project_id,
            name="sqs-credentials",
            permissions={
                "can_manage": True,
                "can_receive": False,
                "can_publish": False,
            })
        dead_letter = scaleway.mnq.SqsQueue("dead_letter",
            project_id=main.project_id,
            name="dead-letter-queue",
            sqs_endpoint=main.endpoint,
            access_key=main_sqs_credentials.access_key,
            secret_key=main_sqs_credentials.secret_key)
        main_sqs_queue = scaleway.mnq.SqsQueue("main",
            project_id=main.project_id,
            name="my-queue",
            sqs_endpoint=main.endpoint,
            access_key=main_sqs_credentials.access_key,
            secret_key=main_sqs_credentials.secret_key,
            dead_letter_queue={
                "id": dead_letter.id,
                "max_receive_count": 3,
            })
        ```

        ## Dead Letter Queue

        The `dead_letter_queue` block supports the following:

        - `id` - (Required) The ID of the dead letter queue. Can be either in the format `{region}/{project-id}/{queue-name}` or `arn:scw:sqs:{region}:project-{project-id}:{queue-name}`.

        - `max_receive_count` - (Required) The number of times a message is delivered to the source queue before being moved to the dead letter queue. Must be between 1 and 1000.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_key: The access key of the SQS queue.
        :param pulumi.Input[_builtins.bool] content_based_deduplication: Specifies whether to enable content-based deduplication. Defaults to `false`.
        :param pulumi.Input[Union['SqsQueueDeadLetterQueueArgs', 'SqsQueueDeadLetterQueueArgsDict']] dead_letter_queue: Configuration for the dead letter queue. See Dead Letter Queue below for details.
        :param pulumi.Input[_builtins.bool] fifo_queue: Whether the queue is a FIFO queue. If true, the queue name must end with .fifo. Defaults to `false`.
        :param pulumi.Input[_builtins.int] message_max_age: The number of seconds the queue retains a message. Must be between 60 and 1_209_600. Defaults to 345_600.
        :param pulumi.Input[_builtins.int] message_max_size: The maximum size of a message. Should be in bytes. Must be between 1024 and 262_144. Defaults to 262_144.
        :param pulumi.Input[_builtins.str] name: The unique name of the SQS queue. Either `name` or `name_prefix` is required. Conflicts with `name_prefix`.
        :param pulumi.Input[_builtins.str] name_prefix: Creates a unique name beginning with the specified prefix. Conflicts with `name`.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project in which SQS is enabled.
        :param pulumi.Input[_builtins.int] receive_wait_time_seconds: The number of seconds to wait for a message to arrive in the queue before returning. Must be between 0 and 20. Defaults to 0.
        :param pulumi.Input[_builtins.str] region: `region`). The region in which SQS is enabled.
        :param pulumi.Input[_builtins.str] secret_key: The secret key of the SQS queue.
        :param pulumi.Input[_builtins.str] sqs_endpoint: The endpoint of the SQS queue. Can contain a {region} placeholder. Defaults to `https://sqs.mnq.{region}.scaleway.com`.
        :param pulumi.Input[_builtins.int] visibility_timeout_seconds: The number of seconds a message is hidden from other consumers. Must be between 0 and 43_200. Defaults to 30.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SqsQueueArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Messaging and Queuing SQS queues.
        For further information, see
        our [main documentation](https://www.scaleway.com/en/docs/messaging/how-to/create-manage-queues/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.mnq.Sqs("main")
        main_sqs_credentials = scaleway.mnq.SqsCredentials("main",
            project_id=main.project_id,
            name="sqs-credentials",
            permissions={
                "can_manage": True,
                "can_receive": False,
                "can_publish": False,
            })
        main_sqs_queue = scaleway.mnq.SqsQueue("main",
            project_id=main.project_id,
            name="my-queue",
            sqs_endpoint=main.endpoint,
            access_key=main_sqs_credentials.access_key,
            secret_key=main_sqs_credentials.secret_key)
        ```

        ### With Dead Letter Queue

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.mnq.Sqs("main")
        main_sqs_credentials = scaleway.mnq.SqsCredentials("main",
            project_id=main.project_id,
            name="sqs-credentials",
            permissions={
                "can_manage": True,
                "can_receive": False,
                "can_publish": False,
            })
        dead_letter = scaleway.mnq.SqsQueue("dead_letter",
            project_id=main.project_id,
            name="dead-letter-queue",
            sqs_endpoint=main.endpoint,
            access_key=main_sqs_credentials.access_key,
            secret_key=main_sqs_credentials.secret_key)
        main_sqs_queue = scaleway.mnq.SqsQueue("main",
            project_id=main.project_id,
            name="my-queue",
            sqs_endpoint=main.endpoint,
            access_key=main_sqs_credentials.access_key,
            secret_key=main_sqs_credentials.secret_key,
            dead_letter_queue={
                "id": dead_letter.id,
                "max_receive_count": 3,
            })
        ```

        ## Dead Letter Queue

        The `dead_letter_queue` block supports the following:

        - `id` - (Required) The ID of the dead letter queue. Can be either in the format `{region}/{project-id}/{queue-name}` or `arn:scw:sqs:{region}:project-{project-id}:{queue-name}`.

        - `max_receive_count` - (Required) The number of times a message is delivered to the source queue before being moved to the dead letter queue. Must be between 1 and 1000.

        :param str resource_name: The name of the resource.
        :param SqsQueueArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SqsQueueArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 content_based_deduplication: Optional[pulumi.Input[_builtins.bool]] = None,
                 dead_letter_queue: Optional[pulumi.Input[Union['SqsQueueDeadLetterQueueArgs', 'SqsQueueDeadLetterQueueArgsDict']]] = None,
                 fifo_queue: Optional[pulumi.Input[_builtins.bool]] = None,
                 message_max_age: Optional[pulumi.Input[_builtins.int]] = None,
                 message_max_size: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 name_prefix: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 receive_wait_time_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 sqs_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 visibility_timeout_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SqsQueueArgs.__new__(SqsQueueArgs)

            if access_key is None and not opts.urn:
                raise TypeError("Missing required property 'access_key'")
            __props__.__dict__["access_key"] = None if access_key is None else pulumi.Output.secret(access_key)
            __props__.__dict__["content_based_deduplication"] = content_based_deduplication
            __props__.__dict__["dead_letter_queue"] = dead_letter_queue
            __props__.__dict__["fifo_queue"] = fifo_queue
            __props__.__dict__["message_max_age"] = message_max_age
            __props__.__dict__["message_max_size"] = message_max_size
            __props__.__dict__["name"] = name
            __props__.__dict__["name_prefix"] = name_prefix
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["receive_wait_time_seconds"] = receive_wait_time_seconds
            __props__.__dict__["region"] = region
            if secret_key is None and not opts.urn:
                raise TypeError("Missing required property 'secret_key'")
            __props__.__dict__["secret_key"] = None if secret_key is None else pulumi.Output.secret(secret_key)
            __props__.__dict__["sqs_endpoint"] = sqs_endpoint
            __props__.__dict__["visibility_timeout_seconds"] = visibility_timeout_seconds
            __props__.__dict__["arn"] = None
            __props__.__dict__["url"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="scaleway:index/mnqSqsQueue:MnqSqsQueue")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["accessKey", "secretKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(SqsQueue, __self__).__init__(
            'scaleway:mnq/sqsQueue:SqsQueue',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_key: Optional[pulumi.Input[_builtins.str]] = None,
            arn: Optional[pulumi.Input[_builtins.str]] = None,
            content_based_deduplication: Optional[pulumi.Input[_builtins.bool]] = None,
            dead_letter_queue: Optional[pulumi.Input[Union['SqsQueueDeadLetterQueueArgs', 'SqsQueueDeadLetterQueueArgsDict']]] = None,
            fifo_queue: Optional[pulumi.Input[_builtins.bool]] = None,
            message_max_age: Optional[pulumi.Input[_builtins.int]] = None,
            message_max_size: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            name_prefix: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            receive_wait_time_seconds: Optional[pulumi.Input[_builtins.int]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            secret_key: Optional[pulumi.Input[_builtins.str]] = None,
            sqs_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
            url: Optional[pulumi.Input[_builtins.str]] = None,
            visibility_timeout_seconds: Optional[pulumi.Input[_builtins.int]] = None) -> 'SqsQueue':
        """
        Get an existing SqsQueue resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_key: The access key of the SQS queue.
        :param pulumi.Input[_builtins.str] arn: The ARN of the queue
        :param pulumi.Input[_builtins.bool] content_based_deduplication: Specifies whether to enable content-based deduplication. Defaults to `false`.
        :param pulumi.Input[Union['SqsQueueDeadLetterQueueArgs', 'SqsQueueDeadLetterQueueArgsDict']] dead_letter_queue: Configuration for the dead letter queue. See Dead Letter Queue below for details.
        :param pulumi.Input[_builtins.bool] fifo_queue: Whether the queue is a FIFO queue. If true, the queue name must end with .fifo. Defaults to `false`.
        :param pulumi.Input[_builtins.int] message_max_age: The number of seconds the queue retains a message. Must be between 60 and 1_209_600. Defaults to 345_600.
        :param pulumi.Input[_builtins.int] message_max_size: The maximum size of a message. Should be in bytes. Must be between 1024 and 262_144. Defaults to 262_144.
        :param pulumi.Input[_builtins.str] name: The unique name of the SQS queue. Either `name` or `name_prefix` is required. Conflicts with `name_prefix`.
        :param pulumi.Input[_builtins.str] name_prefix: Creates a unique name beginning with the specified prefix. Conflicts with `name`.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project in which SQS is enabled.
        :param pulumi.Input[_builtins.int] receive_wait_time_seconds: The number of seconds to wait for a message to arrive in the queue before returning. Must be between 0 and 20. Defaults to 0.
        :param pulumi.Input[_builtins.str] region: `region`). The region in which SQS is enabled.
        :param pulumi.Input[_builtins.str] secret_key: The secret key of the SQS queue.
        :param pulumi.Input[_builtins.str] sqs_endpoint: The endpoint of the SQS queue. Can contain a {region} placeholder. Defaults to `https://sqs.mnq.{region}.scaleway.com`.
        :param pulumi.Input[_builtins.str] url: The URL of the queue.
        :param pulumi.Input[_builtins.int] visibility_timeout_seconds: The number of seconds a message is hidden from other consumers. Must be between 0 and 43_200. Defaults to 30.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SqsQueueState.__new__(_SqsQueueState)

        __props__.__dict__["access_key"] = access_key
        __props__.__dict__["arn"] = arn
        __props__.__dict__["content_based_deduplication"] = content_based_deduplication
        __props__.__dict__["dead_letter_queue"] = dead_letter_queue
        __props__.__dict__["fifo_queue"] = fifo_queue
        __props__.__dict__["message_max_age"] = message_max_age
        __props__.__dict__["message_max_size"] = message_max_size
        __props__.__dict__["name"] = name
        __props__.__dict__["name_prefix"] = name_prefix
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["receive_wait_time_seconds"] = receive_wait_time_seconds
        __props__.__dict__["region"] = region
        __props__.__dict__["secret_key"] = secret_key
        __props__.__dict__["sqs_endpoint"] = sqs_endpoint
        __props__.__dict__["url"] = url
        __props__.__dict__["visibility_timeout_seconds"] = visibility_timeout_seconds
        return SqsQueue(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> pulumi.Output[_builtins.str]:
        """
        The access key of the SQS queue.
        """
        return pulumi.get(self, "access_key")

    @_builtins.property
    @pulumi.getter
    def arn(self) -> pulumi.Output[_builtins.str]:
        """
        The ARN of the queue
        """
        return pulumi.get(self, "arn")

    @_builtins.property
    @pulumi.getter(name="contentBasedDeduplication")
    def content_based_deduplication(self) -> pulumi.Output[_builtins.bool]:
        """
        Specifies whether to enable content-based deduplication. Defaults to `false`.
        """
        return pulumi.get(self, "content_based_deduplication")

    @_builtins.property
    @pulumi.getter(name="deadLetterQueue")
    def dead_letter_queue(self) -> pulumi.Output[Optional['outputs.SqsQueueDeadLetterQueue']]:
        """
        Configuration for the dead letter queue. See Dead Letter Queue below for details.
        """
        return pulumi.get(self, "dead_letter_queue")

    @_builtins.property
    @pulumi.getter(name="fifoQueue")
    def fifo_queue(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the queue is a FIFO queue. If true, the queue name must end with .fifo. Defaults to `false`.
        """
        return pulumi.get(self, "fifo_queue")

    @_builtins.property
    @pulumi.getter(name="messageMaxAge")
    def message_max_age(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The number of seconds the queue retains a message. Must be between 60 and 1_209_600. Defaults to 345_600.
        """
        return pulumi.get(self, "message_max_age")

    @_builtins.property
    @pulumi.getter(name="messageMaxSize")
    def message_max_size(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The maximum size of a message. Should be in bytes. Must be between 1024 and 262_144. Defaults to 262_144.
        """
        return pulumi.get(self, "message_max_size")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The unique name of the SQS queue. Either `name` or `name_prefix` is required. Conflicts with `name_prefix`.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="namePrefix")
    def name_prefix(self) -> pulumi.Output[_builtins.str]:
        """
        Creates a unique name beginning with the specified prefix. Conflicts with `name`.
        """
        return pulumi.get(self, "name_prefix")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the Project in which SQS is enabled.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="receiveWaitTimeSeconds")
    def receive_wait_time_seconds(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The number of seconds to wait for a message to arrive in the queue before returning. Must be between 0 and 20. Defaults to 0.
        """
        return pulumi.get(self, "receive_wait_time_seconds")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`). The region in which SQS is enabled.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> pulumi.Output[_builtins.str]:
        """
        The secret key of the SQS queue.
        """
        return pulumi.get(self, "secret_key")

    @_builtins.property
    @pulumi.getter(name="sqsEndpoint")
    def sqs_endpoint(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The endpoint of the SQS queue. Can contain a {region} placeholder. Defaults to `https://sqs.mnq.{region}.scaleway.com`.
        """
        return pulumi.get(self, "sqs_endpoint")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL of the queue.
        """
        return pulumi.get(self, "url")

    @_builtins.property
    @pulumi.getter(name="visibilityTimeoutSeconds")
    def visibility_timeout_seconds(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The number of seconds a message is hidden from other consumers. Must be between 0 and 43_200. Defaults to 30.
        """
        return pulumi.get(self, "visibility_timeout_seconds")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstanceGroupResult',
    'AwaitableGetInstanceGroupResult',
    'get_instance_group',
    'get_instance_group_output',
]

@pulumi.output_type
class GetInstanceGroupResult:
    """
    A collection of values returned by getInstanceGroup.
    """
    def __init__(__self__, capacities=None, created_at=None, delete_servers_on_destroy=None, id=None, instance_group_id=None, load_balancers=None, name=None, project_id=None, tags=None, template_id=None, updated_at=None, zone=None):
        if capacities and not isinstance(capacities, list):
            raise TypeError("Expected argument 'capacities' to be a list")
        pulumi.set(__self__, "capacities", capacities)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if delete_servers_on_destroy and not isinstance(delete_servers_on_destroy, bool):
            raise TypeError("Expected argument 'delete_servers_on_destroy' to be a bool")
        pulumi.set(__self__, "delete_servers_on_destroy", delete_servers_on_destroy)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_group_id and not isinstance(instance_group_id, str):
            raise TypeError("Expected argument 'instance_group_id' to be a str")
        pulumi.set(__self__, "instance_group_id", instance_group_id)
        if load_balancers and not isinstance(load_balancers, list):
            raise TypeError("Expected argument 'load_balancers' to be a list")
        pulumi.set(__self__, "load_balancers", load_balancers)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if template_id and not isinstance(template_id, str):
            raise TypeError("Expected argument 'template_id' to be a str")
        pulumi.set(__self__, "template_id", template_id)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter
    def capacities(self) -> Sequence['outputs.GetInstanceGroupCapacityResult']:
        return pulumi.get(self, "capacities")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="deleteServersOnDestroy")
    def delete_servers_on_destroy(self) -> _builtins.bool:
        return pulumi.get(self, "delete_servers_on_destroy")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="instanceGroupId")
    def instance_group_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "instance_group_id")

    @_builtins.property
    @pulumi.getter(name="loadBalancers")
    def load_balancers(self) -> Sequence['outputs.GetInstanceGroupLoadBalancerResult']:
        return pulumi.get(self, "load_balancers")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="templateId")
    def template_id(self) -> _builtins.str:
        return pulumi.get(self, "template_id")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "zone")


class AwaitableGetInstanceGroupResult(GetInstanceGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceGroupResult(
            capacities=self.capacities,
            created_at=self.created_at,
            delete_servers_on_destroy=self.delete_servers_on_destroy,
            id=self.id,
            instance_group_id=self.instance_group_id,
            load_balancers=self.load_balancers,
            name=self.name,
            project_id=self.project_id,
            tags=self.tags,
            template_id=self.template_id,
            updated_at=self.updated_at,
            zone=self.zone)


def get_instance_group(instance_group_id: Optional[_builtins.str] = None,
                       name: Optional[_builtins.str] = None,
                       zone: Optional[_builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceGroupResult:
    """
    Gets information about an Autoscaling Instance group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by name
    by_name = scaleway.autoscaling.get_instance_group(name="my-instance-group")
    # Get info by ID
    by_id = scaleway.autoscaling.get_instance_group(instance_group_id="11111111-1111-1111-1111-111111111111")
    ```


    :param _builtins.str instance_group_id: The ID of the Instance group. Only one of `name` and `instance_group_id` should be specified.
    :param _builtins.str name: The name of the Instance group. Only one of `name` and `instance_group_id` should be specified.
    :param _builtins.str zone: `zone`) The zone in which the Instance group exists.
    """
    __args__ = dict()
    __args__['instanceGroupId'] = instance_group_id
    __args__['name'] = name
    __args__['zone'] = zone
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:autoscaling/getInstanceGroup:getInstanceGroup', __args__, opts=opts, typ=GetInstanceGroupResult).value

    return AwaitableGetInstanceGroupResult(
        capacities=pulumi.get(__ret__, 'capacities'),
        created_at=pulumi.get(__ret__, 'created_at'),
        delete_servers_on_destroy=pulumi.get(__ret__, 'delete_servers_on_destroy'),
        id=pulumi.get(__ret__, 'id'),
        instance_group_id=pulumi.get(__ret__, 'instance_group_id'),
        load_balancers=pulumi.get(__ret__, 'load_balancers'),
        name=pulumi.get(__ret__, 'name'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tags=pulumi.get(__ret__, 'tags'),
        template_id=pulumi.get(__ret__, 'template_id'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        zone=pulumi.get(__ret__, 'zone'))
def get_instance_group_output(instance_group_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              zone: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstanceGroupResult]:
    """
    Gets information about an Autoscaling Instance group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by name
    by_name = scaleway.autoscaling.get_instance_group(name="my-instance-group")
    # Get info by ID
    by_id = scaleway.autoscaling.get_instance_group(instance_group_id="11111111-1111-1111-1111-111111111111")
    ```


    :param _builtins.str instance_group_id: The ID of the Instance group. Only one of `name` and `instance_group_id` should be specified.
    :param _builtins.str name: The name of the Instance group. Only one of `name` and `instance_group_id` should be specified.
    :param _builtins.str zone: `zone`) The zone in which the Instance group exists.
    """
    __args__ = dict()
    __args__['instanceGroupId'] = instance_group_id
    __args__['name'] = name
    __args__['zone'] = zone
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:autoscaling/getInstanceGroup:getInstanceGroup', __args__, opts=opts, typ=GetInstanceGroupResult)
    return __ret__.apply(lambda __response__: GetInstanceGroupResult(
        capacities=pulumi.get(__response__, 'capacities'),
        created_at=pulumi.get(__response__, 'created_at'),
        delete_servers_on_destroy=pulumi.get(__response__, 'delete_servers_on_destroy'),
        id=pulumi.get(__response__, 'id'),
        instance_group_id=pulumi.get(__response__, 'instance_group_id'),
        load_balancers=pulumi.get(__response__, 'load_balancers'),
        name=pulumi.get(__response__, 'name'),
        project_id=pulumi.get(__response__, 'project_id'),
        tags=pulumi.get(__response__, 'tags'),
        template_id=pulumi.get(__response__, 'template_id'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        zone=pulumi.get(__response__, 'zone')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .acl import *
from .connector import *
from .gateway_network import *
from .get_acl import *
from .get_connector import *
from .get_gateway_network import *
from .get_private_network import *
from .get_public_gateway import *
from .get_public_gateway_dhcp import *
from .get_public_gateway_dhcp_reservation import *
from .get_public_gateway_ip import *
from .get_public_gateway_pat_rule import *
from .get_route import *
from .get_routes import *
from .get_vpc import *
from .get_vpcs import *
from .private_network import *
from .public_gateway import *
from .public_gateway_dhcp import *
from .public_gateway_dhcp_reservation import *
from .public_gateway_ip import *
from .public_gateway_ip_reverse_dns import *
from .public_gateway_pat_rule import *
from .route import *
from .vpc import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetGatewayResult',
    'AwaitableGetGatewayResult',
    'get_gateway',
    'get_gateway_output',
]

@pulumi.output_type
class GetGatewayResult:
    """
    A collection of values returned by getGateway.
    """
    def __init__(__self__, asn=None, created_at=None, gateway_type=None, id=None, ipam_private_ipv4_id=None, ipam_private_ipv6_id=None, name=None, organization_id=None, private_network_id=None, project_id=None, public_configs=None, region=None, status=None, tags=None, updated_at=None, vpn_gateway_id=None, zone=None):
        if asn and not isinstance(asn, int):
            raise TypeError("Expected argument 'asn' to be a int")
        pulumi.set(__self__, "asn", asn)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if gateway_type and not isinstance(gateway_type, str):
            raise TypeError("Expected argument 'gateway_type' to be a str")
        pulumi.set(__self__, "gateway_type", gateway_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ipam_private_ipv4_id and not isinstance(ipam_private_ipv4_id, str):
            raise TypeError("Expected argument 'ipam_private_ipv4_id' to be a str")
        pulumi.set(__self__, "ipam_private_ipv4_id", ipam_private_ipv4_id)
        if ipam_private_ipv6_id and not isinstance(ipam_private_ipv6_id, str):
            raise TypeError("Expected argument 'ipam_private_ipv6_id' to be a str")
        pulumi.set(__self__, "ipam_private_ipv6_id", ipam_private_ipv6_id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if private_network_id and not isinstance(private_network_id, str):
            raise TypeError("Expected argument 'private_network_id' to be a str")
        pulumi.set(__self__, "private_network_id", private_network_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if public_configs and not isinstance(public_configs, list):
            raise TypeError("Expected argument 'public_configs' to be a list")
        pulumi.set(__self__, "public_configs", public_configs)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if vpn_gateway_id and not isinstance(vpn_gateway_id, str):
            raise TypeError("Expected argument 'vpn_gateway_id' to be a str")
        pulumi.set(__self__, "vpn_gateway_id", vpn_gateway_id)
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter
    def asn(self) -> _builtins.int:
        """
        The AS Number of the VPN gateway.
        """
        return pulumi.get(self, "asn")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        The date and time of creation of the VPN gateway.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="gatewayType")
    def gateway_type(self) -> _builtins.str:
        """
        The VPN gateway type (commercial offer type).
        """
        return pulumi.get(self, "gateway_type")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="ipamPrivateIpv4Id")
    def ipam_private_ipv4_id(self) -> _builtins.str:
        """
        The ID of the IPAM private IPv4 address attached to the VPN gateway.
        """
        return pulumi.get(self, "ipam_private_ipv4_id")

    @_builtins.property
    @pulumi.getter(name="ipamPrivateIpv6Id")
    def ipam_private_ipv6_id(self) -> _builtins.str:
        """
        The ID of the IPAM private IPv6 address attached to the VPN gateway.
        """
        return pulumi.get(self, "ipam_private_ipv6_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> _builtins.str:
        """
        The Organization ID the VPN gateway is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> _builtins.str:
        """
        The ID of the Private Network attached to the VPN gateway.
        """
        return pulumi.get(self, "private_network_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="publicConfigs")
    def public_configs(self) -> Sequence['outputs.GetGatewayPublicConfigResult']:
        """
        The public endpoint configuration of the VPN gateway.
        """
        return pulumi.get(self, "public_configs")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The status of the VPN gateway.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        The tags associated with the VPN gateway.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        The date and time of the last update of the VPN gateway.
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="vpnGatewayId")
    def vpn_gateway_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "vpn_gateway_id")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> _builtins.str:
        """
        The zone in which the VPN gateway is deployed.
        """
        return pulumi.get(self, "zone")


class AwaitableGetGatewayResult(GetGatewayResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGatewayResult(
            asn=self.asn,
            created_at=self.created_at,
            gateway_type=self.gateway_type,
            id=self.id,
            ipam_private_ipv4_id=self.ipam_private_ipv4_id,
            ipam_private_ipv6_id=self.ipam_private_ipv6_id,
            name=self.name,
            organization_id=self.organization_id,
            private_network_id=self.private_network_id,
            project_id=self.project_id,
            public_configs=self.public_configs,
            region=self.region,
            status=self.status,
            tags=self.tags,
            updated_at=self.updated_at,
            vpn_gateway_id=self.vpn_gateway_id,
            zone=self.zone)


def get_gateway(name: Optional[_builtins.str] = None,
                project_id: Optional[_builtins.str] = None,
                region: Optional[_builtins.str] = None,
                vpn_gateway_id: Optional[_builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGatewayResult:
    """
    For further information refer to the Site-to-Site VPN [API documentation](https://www.scaleway.com/en/developers/api/site-to-site-vpn/).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by gateway ID
    my_gateway = scaleway.s2svpn.get_gateway(vpn_gateway_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by name
    my_gateway = scaleway.s2svpn.get_gateway(name="foobar")
    ```


    :param _builtins.str name: The name of the VPN gateway.
    :param _builtins.str project_id: The ID of the project the VPN gateway is associated with.
    :param _builtins.str region: `region`) The region in which the VPN gateway exists.
    :param _builtins.str vpn_gateway_id: The VPN gateway ID.
           
           > **Note** You must specify at least one: `name` and/or `vpn_gateway_id`.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    __args__['vpnGatewayId'] = vpn_gateway_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:s2svpn/getGateway:getGateway', __args__, opts=opts, typ=GetGatewayResult).value

    return AwaitableGetGatewayResult(
        asn=pulumi.get(__ret__, 'asn'),
        created_at=pulumi.get(__ret__, 'created_at'),
        gateway_type=pulumi.get(__ret__, 'gateway_type'),
        id=pulumi.get(__ret__, 'id'),
        ipam_private_ipv4_id=pulumi.get(__ret__, 'ipam_private_ipv4_id'),
        ipam_private_ipv6_id=pulumi.get(__ret__, 'ipam_private_ipv6_id'),
        name=pulumi.get(__ret__, 'name'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        private_network_id=pulumi.get(__ret__, 'private_network_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        public_configs=pulumi.get(__ret__, 'public_configs'),
        region=pulumi.get(__ret__, 'region'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        vpn_gateway_id=pulumi.get(__ret__, 'vpn_gateway_id'),
        zone=pulumi.get(__ret__, 'zone'))
def get_gateway_output(name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       vpn_gateway_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGatewayResult]:
    """
    For further information refer to the Site-to-Site VPN [API documentation](https://www.scaleway.com/en/developers/api/site-to-site-vpn/).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by gateway ID
    my_gateway = scaleway.s2svpn.get_gateway(vpn_gateway_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by name
    my_gateway = scaleway.s2svpn.get_gateway(name="foobar")
    ```


    :param _builtins.str name: The name of the VPN gateway.
    :param _builtins.str project_id: The ID of the project the VPN gateway is associated with.
    :param _builtins.str region: `region`) The region in which the VPN gateway exists.
    :param _builtins.str vpn_gateway_id: The VPN gateway ID.
           
           > **Note** You must specify at least one: `name` and/or `vpn_gateway_id`.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    __args__['vpnGatewayId'] = vpn_gateway_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:s2svpn/getGateway:getGateway', __args__, opts=opts, typ=GetGatewayResult)
    return __ret__.apply(lambda __response__: GetGatewayResult(
        asn=pulumi.get(__response__, 'asn'),
        created_at=pulumi.get(__response__, 'created_at'),
        gateway_type=pulumi.get(__response__, 'gateway_type'),
        id=pulumi.get(__response__, 'id'),
        ipam_private_ipv4_id=pulumi.get(__response__, 'ipam_private_ipv4_id'),
        ipam_private_ipv6_id=pulumi.get(__response__, 'ipam_private_ipv6_id'),
        name=pulumi.get(__response__, 'name'),
        organization_id=pulumi.get(__response__, 'organization_id'),
        private_network_id=pulumi.get(__response__, 'private_network_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        public_configs=pulumi.get(__response__, 'public_configs'),
        region=pulumi.get(__response__, 'region'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        vpn_gateway_id=pulumi.get(__response__, 'vpn_gateway_id'),
        zone=pulumi.get(__response__, 'zone')))
